/**
 * Utility functions for API URL handling
 */

/**
 * Get the API URL from configuration or auto-detect it
 * @returns The API URL without trailing slash
 */
export function getApiUrl(): string {
  console.log("[API-URL] Getting API URL");

  // Get the API URL from window.appConfig or environment variables
  let apiUrl = window.appConfig?.apiUrl || import.meta.env.CLIENT_API_URL;
  console.log(`[API-URL] Initial API URL value: ${apiUrl}`);

  // Auto-detect API URL if set to 'DETECT'
  if (typeof apiUrl === "string" && apiUrl.toUpperCase() === "DETECT") {
    console.log("[API-URL] Auto-detection triggered: apiUrl is 'DETECT'");

    try {
      const url = new URL(window.location.href);
      console.log(`[API-URL] Current window.location: ${window.location.href}`);

      const pathSegments = url.pathname.split("/").filter(Boolean);
      console.log(`[API-URL] Path segments: ${JSON.stringify(pathSegments)}`);

      const basePath = pathSegments.length > 0 ? `/${pathSegments[0]}/` : "/";
      console.log(`[API-URL] Base path: ${basePath}`);

      apiUrl = `${url.origin}${basePath}`;
      console.log(`[API-URL] Detected API URL: ${apiUrl}`);
    } catch (error) {
      console.error(
        "[API-URL] FATAL ERROR: Failed to auto-detect API URL:",
        error,
      );
      throw new Error("Failed to auto-detect API URL");
    }
  } else {
    console.log(
      `[API-URL] No auto-detection needed: apiUrl is not 'DETECT' (value: ${apiUrl})`,
    );
  }

  if (!apiUrl) {
    const errorMsg =
      "API URL is not defined in window.appConfig.apiUrl or environment variables";
    console.error(`[API-URL] FATAL ERROR: ${errorMsg}`);
    throw new Error(errorMsg);
  }

  try {
    // For API URLs, we should NOT have a trailing slash
    // This is different from normalizeUrl which adds a trailing slash
    const apiUrlWithoutTrailingSlash = apiUrl.endsWith("/")
      ? apiUrl.slice(0, -1)
      : apiUrl;
    console.log(
      `[API-URL] API URL without trailing slash: ${apiUrlWithoutTrailingSlash}`,
    );
    return apiUrlWithoutTrailingSlash;
  } catch (error) {
    console.error(`[API-URL] Error normalizing API URL: ${apiUrl}`, error);
    // Return the original URL if normalization fails
    return apiUrl;
  }
}

// Singleton instance of the API URL
let apiUrlInstance: string | null = null;

/**
 * Get the API URL (singleton pattern)
 * @returns The API URL without trailing slash
 */
export function getApiUrlSingleton(): string {
  if (!apiUrlInstance) {
    apiUrlInstance = getApiUrl();
  }
  return apiUrlInstance;
}
