/**
 * Utility functions for diagnosing environment and configuration issues
 */

/**
 * Checks if the CLIENT_API_URL environment variable is properly set
 * and logs diagnostic information to the console
 */
export const checkApiUrlConfig = () => {
  console.log("=== API URL Configuration Diagnostics ===");

  // Check if window.appConfig exists and has apiUrl
  const apiUrl = window.appConfig?.apiUrl;
  console.log(`window.appConfig.apiUrl: ${apiUrl || "NOT DEFINED"}`);

  // For backward compatibility, also check import.meta.env
  const metaApiUrl = import.meta.env.CLIENT_API_URL;
  console.log(
    `import.meta.env.CLIENT_API_URL: ${metaApiUrl || "NOT DEFINED"} (legacy)`,
  );

  // Check if we're in development or production mode
  console.log(`Environment mode: ${import.meta.env.MODE}`);

  // Log all window.appConfig properties (without exposing sensitive values)
  console.log("All window.appConfig properties:");
  if (window.appConfig) {
    Object.keys(window.appConfig).forEach((key) => {
      const value = window.appConfig?.[key];
      // Don't log actual values of potentially sensitive information
      if (
        key.toLowerCase().includes("key") ||
        key.toLowerCase().includes("secret") ||
        key.toLowerCase().includes("password") ||
        key.toLowerCase().includes("token")
      ) {
        console.log(`  ${key}: [REDACTED]`);
      } else {
        console.log(`  ${key}: ${value || "NOT DEFINED"}`);
      }
    });
  } else {
    console.log("  window.appConfig is not defined!");
  }

  console.log("=======================================");

  // Return the API URL for convenience
  return apiUrl || metaApiUrl;
};
