/**
 * Utility functions for URL handling
 */

/**
 * Safely joins URL parts, handling slashes correctly
 * @param base The base URL
 * @param paths Additional path segments to append
 * @returns A properly formatted URL
 */
export function joinUrl(base: string, ...paths: string[]): string {
  try {
    // Handle empty base case
    if (!base) {
      return "";
    }

    // Ensure base has a trailing slash for URL constructor
    const baseWithTrailingSlash = base.endsWith("/") ? base : `${base}/`;

    // Create a URL object from the base
    const url = new URL(baseWithTrailingSlash);

    // Join all path segments, removing leading and trailing slashes
    const pathSegments = paths
      .filter(Boolean) // Filter out empty segments
      .map((path) => path.replace(/^\/|\/$/g, "")); // Remove leading and trailing slashes

    // If we have path segments, append them to the pathname
    if (pathSegments.length > 0) {
      // Get the base pathname without trailing slash
      const basePathname = url.pathname.replace(/\/$/, "");

      // Join all paths with a single slash
      url.pathname = `${basePathname}/${pathSegments.join("/")}`;
    }

    return url.toString();
  } catch (error) {
    console.error(
      `Error joining URL parts (${base}, ${paths.join(", ")}):`,
      error,
    );
    // Fallback to simple string concatenation
    return [
      base.replace(/\/$/, ""),
      ...paths.map((p) => p.replace(/^\/|\/$/g, "")),
    ]
      .filter(Boolean)
      .join("/");
  }
}

/**
 * Creates a properly formatted hash URL
 * @param base The base URL (usually window.location.origin)
 * @param basePath Optional base path
 * @param hashPath The hash path (without the # symbol)
 * @returns A properly formatted URL with hash
 */
export function createHashUrl(
  base: string,
  basePath: string | undefined,
  hashPath: string,
): string {
  try {
    // Ensure base has a trailing slash for URL constructor
    const baseWithTrailingSlash = base.endsWith("/") ? base : `${base}/`;

    // Create a URL object from the base
    const url = new URL(baseWithTrailingSlash);

    // Add the base path if it exists
    if (basePath) {
      // Remove leading and trailing slashes from basePath
      const cleanBasePath = basePath.replace(/^\/|\/$/g, "");
      if (cleanBasePath) {
        // Ensure the pathname ends with a slash before adding the hash
        url.pathname = `/${cleanBasePath}/`;
      }
    } else {
      // If no base path, ensure the pathname is at least '/'
      url.pathname = url.pathname.endsWith("/")
        ? url.pathname
        : `${url.pathname}/`;
    }

    // Add the hash path
    // Remove leading slash from hashPath if it exists
    const cleanHashPath = hashPath.replace(/^\//, "");
    // Always include a leading slash after the hash symbol

    // Remove /#/
    if (cleanHashPath === "/" || cleanHashPath === "") url.hash = "";
    else {
      url.hash = cleanHashPath ? `#/${cleanHashPath}` : "#/";
    }

    return url.toString();
  } catch (error) {
    console.error(
      `Error creating hash URL (${base}, ${basePath}, ${hashPath}):`,
      error,
    );
    // Fallback to simple string concatenation
    const cleanBase = base.replace(/\/$/, "");
    const cleanBasePath = basePath
      ? `/${basePath.replace(/^\/|\/$/g, "")}/`
      : "/";
    const cleanHashPath = hashPath.replace(/^\//, "");
    return `${cleanBase}${cleanBasePath}#/${cleanHashPath}`;
  }
}

/**
 * Normalizes a URL by ensuring if it has a subpath, then it has a trailing slash
 * @param url The URL to normalize
 * @returns The normalized URL with a trailing slash
 */
export function normalizeUrl(url: string): string {
  try {
    const urlObj = new URL(url);

    if (urlObj.pathname === "/") {
      return urlObj.toString();
    }

    return urlObj.toString().endsWith("/")
      ? urlObj.toString()
      : `${urlObj.toString()}/`;

  } catch (error) {
    console.error(`Error normalizing URL (${url}):`, error);
    // Fallback to simple string handling if URL parsing fails
    return url.endsWith("/") ? url : `${url}/`;
  }
}

/**
 * Cleans up the current URL by removing query parameters and hash fragments
 */
export function cleanupUrl(): void {
  if (window.history && window.history.replaceState) {
    const url = new URL(window.location.href);
    // Keep only the origin and pathname
    const cleanUrl = `${url.origin}${url.pathname}`;
    window.history.replaceState({}, document.title, cleanUrl);
    console.log("URL cleaned up:", cleanUrl);
  }
}
