"use client";

import { useState, useRef } from "react";
import { ExternalLink, Upload, Trash2, X } from "react-feather";
import Button from "./Button";

export default function ImageUpload({
  onImageChange,
  maxSize = 5, // in MB
  acceptedTypes = ["image/jpeg", "image/png", "image/jpg"],
  className = "",
}) {
  const [image, setImage] = useState<File | null>(null);
  const [previewUrl, setPreviewUrl] = useState("");
  const [error, setError] = useState("");
  const fileInputRef = useRef<HTMLInputElement>(null);

  const handleImageUpload = (e: React.ChangeEvent<HTMLInputElement>) => {
    const files = e.target.files;
    if (!files || files.length === 0) return;
    const file = files[0];

    // Validate file type
    if (!acceptedTypes.includes(file.type)) {
      setError(
        `Please upload a valid file type: ${acceptedTypes.map((type) => type.split("/")[1]).join(", ")}`,
      );
      return;
    }

    // Validate file size
    if (file.size > maxSize * 1024 * 1024) {
      setError(`Image size should be less than ${maxSize}MB`);
      return;
    }

    setError("");
    setImage(file);

    // Create preview URL
    const reader = new FileReader();
    reader.onloadend = () => {
      if (typeof reader.result === "string") {
        setPreviewUrl(reader.result);
        if (onImageChange) {
          onImageChange(file, reader.result);
        }
      }
    };
    reader.readAsDataURL(file);
  };

  const removeImage = (e: React.MouseEvent<HTMLButtonElement>) => {
    e.stopPropagation();
    setImage(null);
    setPreviewUrl("");
    if (fileInputRef.current) {
      fileInputRef.current.value = "";
    }
    if (onImageChange) {
      onImageChange(null, null);
    }
  };

  const triggerFileInput = () => {
    if (fileInputRef.current) {
      fileInputRef.current.click();
    }
  };

  return (
    <div className={className}>
      {/* Hidden file input */}
      <input
        type="file"
        ref={fileInputRef}
        className="hidden"
        accept={acceptedTypes.join(", ")}
        onChange={handleImageUpload}
      />

      {/* Image upload area */}
      <div
        onClick={triggerFileInput}
        className={`border border-dashed border-input rounded-md h-48 flex flex-col items-center justify-center mb-4 bg-input cursor-pointer relative overflow-hidden ${previewUrl ? "p-0" : "p-4"}`}
      >
        {previewUrl ? (
          <>
            <img
              src={previewUrl || "/placeholder.svg"}
              alt="Preview"
              className="w-full h-full object-cover"
            />
            <div className="absolute inset-0 bg-black bg-opacity-40 opacity-0 hover:opacity-100 transition-opacity flex items-center justify-center">
              <div className="flex gap-2">
                <Button
                  variant="ghost"
                  size="icon"
                  className="bg-secondary bg-opacity-80 text-foreground hover:bg-accent"
                  onClick={(e) => {
                    e.stopPropagation();
                    triggerFileInput();
                  }}
                >
                  <Upload size={18} />
                </Button>
                <Button
                  variant="ghost"
                  size="icon"
                  className="bg-secondary bg-opacity-80 text-foreground hover:bg-accent"
                  onClick={removeImage}
                >
                  <Trash2 size={18} />
                </Button>
              </div>
            </div>
          </>
        ) : (
          <div className="flex flex-col items-center gap-2">
            <ExternalLink size={24} className="text-muted-foreground" />
            <span className="text-sm text-muted-foreground">
              Click to upload an image
            </span>
          </div>
        )}
      </div>

      {/* Error message */}
      {error && <div className="text-red-500 text-sm mb-2">{error}</div>}

      {/* Image details if uploaded */}
      {image && (
        <div className="mt-4 p-3 bg-input rounded-md">
          <div className="flex justify-between items-center">
            <div className="flex items-center gap-2">
              <div className="w-10 h-10 bg-secondary rounded-md flex items-center justify-center">
                <img
                  src={previewUrl || "/placeholder.svg"}
                  alt="Thumbnail"
                  className="w-8 h-8 object-cover rounded"
                />
              </div>
              <div>
                <p className="text-sm text-foreground">{image.name}</p>
                <p className="text-xs text-muted-foreground">
                  {(image.size / 1024).toFixed(1)} KB •{" "}
                  {new Date().toLocaleDateString()}
                </p>
              </div>
            </div>
            <Button
              variant="ghost"
              size="icon"
              className="text-muted-foreground hover:bg-secondary"
              onClick={removeImage}
            >
              <X size={16} />
            </Button>
          </div>
        </div>
      )}
    </div>
  );
}
